# -*- coding: utf-8 -*-
# @Author  : LG

model_dict = {
    'mobile_sam.pt':
        {
            'urls': [
                'https://huggingface.co/yateng/isat_checkpoints/resolve/main/mobile_sam.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/mobile_sam.pt'
            ],
            'memory': '534M',
            'bf16_memory': '390M',
            'params': '40M',
            'image_segment': True,
            'video_segment': False,
        },
    'sam_hq_vit_h.pth':
        {
            'urls': [
                'https://huggingface.co/lkeab/hq-sam/resolve/main/sam_hq_vit_h.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam_hq_vit_h.pth'
            ],
            'memory': '6464M',
            'bf16_memory': '3378M',
            'params': '2.6G',
            'image_segment': True,
            'video_segment': False,
        },
    'sam_hq_vit_l.pth':
        {
            'urls': [
                'https://huggingface.co/lkeab/hq-sam/resolve/main/sam_hq_vit_l.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam_hq_vit_l.pth'
            ],
            'memory': '5016M',
            'bf16_memory': '2634M',
            'params': '1.3G',
            'image_segment': True,
            'video_segment': False,
        },
    'sam_hq_vit_b.pth':
        {
            'urls': [
                'https://huggingface.co/lkeab/hq-sam/resolve/main/sam_hq_vit_b.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam_hq_vit_b.pth'
            ],
            'memory': '3304M',
            'bf16_memory': '1762M',
            'params': '379M',
            'image_segment': True,
            'video_segment': False,
        },
    'sam_hq_vit_tiny.pth':
        {
            'urls': [
                'https://huggingface.co/lkeab/hq-sam/resolve/main/sam_hq_vit_tiny.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam_hq_vit_tiny.pth'
            ],
            'memory': '598M',
            'bf16_memory': '392M',
            'params': '43M',
            'image_segment': True,
            'video_segment': False,
        },
    'sam_vit_h_4b8939.pth':
        {
            'urls': [
                'https://dl.fbaipublicfiles.com/segment_anything/sam_vit_h_4b8939.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam_vit_h_4b8939.pth'
            ],
            'memory': '6462M',
            'bf16_memory': '3378M',
            'params': '2.6G',
            'image_segment': True,
            'video_segment': False,
        },
    'sam_vit_l_0b3195.pth':
        {
            'urls': [
                'https://dl.fbaipublicfiles.com/segment_anything/sam_vit_l_0b3195.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam_vit_l_0b3195.pth'
            ],
            'memory': '5016M',
            'bf16_memory': '2634M',
            'params': '1.3G',
            'image_segment': True,
            'video_segment': False,
        },
    'sam_vit_b_01ec64.pth':
        {
            'urls': [
                'https://dl.fbaipublicfiles.com/segment_anything/sam_vit_b_01ec64.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam_vit_b_01ec64.pth'
            ],
            'memory': '3302M',
            'bf16_memory': '1760M',
            'params': '375M',
            'image_segment': True,
            'video_segment': False,
        },
    'edge_sam.pth':
        {
            'urls': [
                'https://huggingface.co/spaces/chongzhou/EdgeSAM/resolve/main/weights/edge_sam.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/edge_sam.pth'
            ],
            'memory': '360M',
            'bf16_memory': '304M',
            'params': '38.8M',
            'image_segment': True,
            'video_segment': False,
        },
    'edge_sam_3x.pth':
        {
            'urls': [
                'https://huggingface.co/spaces/chongzhou/EdgeSAM/resolve/main/weights/edge_sam_3x.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/edge_sam_3x.pth'
            ],
            'memory': '360M',
            'bf16_memory': '304M',
            'params': '38.8M',
            'image_segment': True,
            'video_segment': False,
        },
    'sam-med2d_b.pth':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam-med2d_b.pth',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam-med2d_b.pth'
            ],
            'memory': '1500M',
            'bf16_memory': '1050M',
            'params': '2.4G',
            'image_segment': True,
            'video_segment': False,
        },
    'sam2_hiera_large.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2_hiera_large.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2_hiera_large.pt'
            ],
            'memory': '3252M',
            'bf16_memory': '2008M',
            'params': '900M',
            'image_segment': True,
            'video_segment': True,
        },
    'sam2_hiera_base_plus.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2_hiera_base_plus.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2_hiera_base_plus.pt'
            ],
            'memory': '1992M',
            'bf16_memory': '1666M',
            'params': '324M',
            'image_segment': True,
            'video_segment': True,
        },
    'sam2_hiera_small.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2_hiera_small.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2_hiera_small.pt'
            ],
            'memory': '1522M',
            'bf16_memory': '1226M',
            'params': '185M',
            'image_segment': True,
            'video_segment': True,
        },
    'sam2_hiera_tiny.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2_hiera_tiny.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2_hiera_tiny.pt'
            ],
            'memory': '1504M',
            'bf16_memory': '1196M',
            'params': '156M',
            'image_segment': True,
            'video_segment': True,
        },
    'sam2.1_hiera_large.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2.1_hiera_large.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2.1_hiera_large.pt'
            ],
            'memory': '3328M',
            'bf16_memory': '2266M',
            'params': '900M',
            'image_segment': True,
            'video_segment': True,
        },
    'sam2.1_hiera_base_plus.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2.1_hiera_base_plus.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2.1_hiera_base_plus.pt'
            ],
            'memory': '2032M',
            'bf16_memory': '1682M',
            'params': '324M',
            'image_segment': True,
            'video_segment': True,
        },
    'sam2.1_hiera_small.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2.1_hiera_small.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2.1_hiera_small.pt'
            ],
            'memory': '1736M',
            'bf16_memory': '1268M',
            'params': '185M',
            'image_segment': True,
            'video_segment': True,
        },
    'sam2.1_hiera_tiny.pt':
        {
            'urls': [
                'https://huggingface.co/yatengLG/ISAT_with_segment_anything_checkpoints/resolve/main/sam2.1_hiera_tiny.pt',
                'https://www.modelscope.cn/api/v1/models/yatengLG/ISAT_with_segment_anything_checkpoints/repo?Revision=master&FilePath=checkpoints/sam2.1_hiera_tiny.pt'
            ],
            'memory': '1574M',
            'bf16_memory': '1194M',
            'params': '156M',
            'image_segment': True,
            'video_segment': True,
        },
}
